from typing import Literal

Position = Literal[
    'static',
    'fixed',
    'absolute',
    'relative',
    'sticky',
]
